==> openshift-model-monitoring-5.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RulesBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RulesBuilder extends io.fabric8.openshift.api.model.monitoring.v1.RulesFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.RulesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.Rules,io.fabric8.openshift.api.model.monitoring.v1.RulesBuilder>{
  public RulesBuilder() {
    this(false);
  }
  public RulesBuilder(java.lang.Boolean validationEnabled) {
    this(new Rules(), validationEnabled);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent) {
    this(fluent, false);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Rules(), validationEnabled);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Rules instance) {
    this(fluent, instance, false);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Rules instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlert(instance.getAlert()); 
    this.validationEnabled = validationEnabled; 
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.Rules instance) {
    this(instance,false);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.Rules instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlert(instance.getAlert()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.Rules build() {
    Rules buildable = new Rules(fluent.getAlert());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RulesBuilder that = (RulesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RulesBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RulesBuilder extends io.fabric8.openshift.api.model.monitoring.v1.RulesFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.RulesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.Rules,io.fabric8.openshift.api.model.monitoring.v1.RulesBuilder>{
  public RulesBuilder() {
    this(false);
  }
  public RulesBuilder(java.lang.Boolean validationEnabled) {
    this(new Rules(), validationEnabled);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent) {
    this(fluent, false);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Rules(), validationEnabled);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Rules instance) {
    this(fluent, instance, false);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Rules instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlert(instance.getAlert()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.Rules instance) {
    this(instance,false);
  }
  public RulesBuilder(io.fabric8.openshift.api.model.monitoring.v1.Rules instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlert(instance.getAlert()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.RulesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.Rules build() {
    Rules buildable = new Rules(fluent.getAlert());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RulesBuilder that = (RulesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
